---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: ''
assignees: ''

---

**Is your feature request related to a problem? Please describe.**
A clear and concise description of what the problem is. Ex. I'm always frustrated when [...]

**Describe the solution you'd like**
A clear and concise description of what you want to happen, formulated as a solution to the above mentioned problem if applicable.

**Describe alternatives you've considered**
Please let us know about alternative solutions or workarounds you have attempted to get the feature to work for you already.

**Additional context**
Please provide any additional context you may think is useful in understanding the issue the feature will address and / or the feature itself. Screenshots are a welcome aid!
